@@ -8,6 +8,12 @@ import lxml
 import tempfile
 import re
 
+try:
+    import debug
+    assert debug
+except ImportError:
+    pass
+
 def arrstrip(arr):
     """ Strip beginning and end blanklines of an array """
     if not arr[0]: arr.pop(0)
@@ -29,7 +35,7 @@ def diff_test(case, valid, test, failpath):
     if testarr != validarr:
         diff = difflib.ndiff(validarr, testarr)
         fh = open(failpath, 'w')
-        fh.write(test.encode('ascii', 'xmlcharrefreplace'))
+        fh.write(test)
         fh.close()
         case.fail("Output doesn't match, file saved to %s.\nDIFF:\n%s" % (failpath, '\n'.join(diff)))
 
@@ -44,7 +50,7 @@ class XmlRfcDummy():
     def __init__(self):
         self.pis = {
             "artworkdelimiter":	None,
-            "artworklines":	0 ,
+            "artworklines":	"0",
             "authorship":	"yes",
             "autobreaks":	"yes",
             "background":	"" ,
@@ -52,37 +58,40 @@ class XmlRfcDummy():
             "comments":		"no" ,
             "docmapping":	"no",
             "editing":		"no",
-            "emoticonic":	"no",
+            #"emoticonic":	"no",
             #"footer":		Unset
             "figurecount":      "no",
             #"header":		Unset
             "inline":		"no",
-            "iprnotified":	"no",
+            #"iprnotified":	"no",
             "linkmailto":	"yes",
             #"linefile":	Unset
             #"needLines":       Unset
             "multiple-initials":"no",
-            "notedraftinprogress": "yes",
+            #"notedraftinprogress": "yes",
+            "orphanlimit":      "2",
             "private":		"",
             "refparent":	"References",
             "rfcedstyle":	"no",
-            "rfcprocack":	"no",
-            "sectionorphan":    5,
-            "slides":		"no",
+            #"rfcprocack":	"no",
+            "sectionorphan":    "4",
+            #"slides":		"no",
             "sortrefs":		"yes",  # different from default
-            "strict":		"no",
+            #"strict":		"no",
             "symrefs":		"yes",
             "tablecount":       "no",
             "text-list-symbols": "o*+-",
             "toc":		"no",
             "tocappendix":	"yes",
-            "tocdepth":		3,
+            "tocdepth":		"3",
             "tocindent":	"yes",
             "tocnarrow":	"yes",
-            "tocompact":	"yes",
+            #"tocompact":	"yes",
+            "tocpagebreak":	"no",
             "topblock":		"yes",
             #"typeout":		Unset
-            "useobject":	"no" ,
+            #"useobject":	"no" ,
+            "widowlimit":       "2",
         }
         self.pis["compact"] = self.pis["rfcedstyle"]
         self.pis["subcompact"] = self.pis["compact"]
@@ -104,37 +113,51 @@ class XmlRfcDummy():
                 self.pis[key] = val
             # Return the new values added
 
+def html_post_rendering(text):
+    return text.encode('ascii', 'xmlcharrefreplace').decode('ascii')
+
 output_format = [
     {
         "ext": "txt",
         "spacefix": xml2rfc.utils.formatXmlWhitespace,
         "unicodefix": xml2rfc.utils.safeReplaceUnicode,
+        "slashfix": xml2rfc.utils.safeTagSlashedWords,
         "writer": xml2rfc.PaginatedTextRfcWriter,
-        "postprocesslines": "post_process_lines"
+        "postrendering": lambda x: x,
+        "postprocesslines": "post_process_lines",
     },
     {
         "ext": "raw.txt",
         "spacefix": xml2rfc.utils.formatXmlWhitespace,
         "unicodefix": xml2rfc.utils.safeReplaceUnicode,
+        "slashfix": xml2rfc.utils.safeTagSlashedWords,
         "writer": xml2rfc.RawTextRfcWriter,
-        "postprocesslines": "post_process_lines"
+        "postrendering": lambda x: x,
+        "postprocesslines": "post_process_lines",
     },
     {
         "ext": "nroff",
         "spacefix": xml2rfc.utils.formatXmlWhitespace,
         "unicodefix": xml2rfc.utils.safeReplaceUnicode,
+        "slashfix": xml2rfc.utils.safeTagSlashedWords,
         "writer": xml2rfc.NroffRfcWriter,
-        "postprocesslines": "post_process_lines"
+        "postrendering": lambda x: x,
+        "postprocesslines": "post_process_lines",
     },
     {
         "ext": "html",
         "spacefix": lambda x: x,
         "unicodefix": lambda x: x,
+        "slashfix": xml2rfc.utils.safeTagSlashedWords,
         "writer": xml2rfc.HtmlRfcWriter,
-        "postprocesslines": "post_process_lines"
+        "postrendering": html_post_rendering,
+        "postprocesslines": "post_process_lines",
     },
 ]
 
+class AnnotatedElement(lxml.etree.ElementBase):
+    pis = None
+
 class WriterElementTest(unittest.TestCase):
     """ Performs tests of isolated XML elements against text writer functions """
 
@@ -144,14 +167,32 @@ class WriterElementTest(unittest.TestCase):
     def function_test(self, name, func_name):
         """ Skeleton method for testing an XML element with a writer function """
         xmlpath = "tests/input/%s.xml" % name
-        element = lxml.etree.parse(xmlpath).getroot()
+        parser = lxml.etree.XMLParser()
+        element_lookup = lxml.etree.ElementDefaultClassLookup(element=AnnotatedElement)
+        parser.set_element_class_lookup(element_lookup)
+        element = lxml.etree.parse(xmlpath, parser).getroot()
+        xmlrfc = XmlRfcDummy()
+        pis = xmlrfc.pis.copy()
+        element.pis = pis
+        elements_cache = []
+        for e in element.iterdescendants():
+            elements_cache.append(e)
+            if e.tag is lxml.etree.PI:
+                xmlrfc.parse_pi(e)
+                pis = xmlrfc.pis.copy()
+            else:
+                if isinstance(e, AnnotatedElement):
+                    e.pis = pis
+
         for format in output_format:
             ext = format["ext"]
             spacefix = format["spacefix"]
             unicodefix = format["unicodefix"]
-            writer = format["writer"](XmlRfcDummy(), quiet=True)
+            slashfix = format["slashfix"]
+            writer = format["writer"](xmlrfc, quiet=True)
             testfunc = getattr(writer, func_name)
             postprocessing = getattr(writer, format["postprocesslines"])
+            postrendering = format['postrendering']
             #
             validpath = "tests/valid/%s.%s" % (name, ext)
             try:
@@ -163,8 +204,9 @@ class WriterElementTest(unittest.TestCase):
             #
             spacefix(element)
             unicodefix(element)
+            slashfix(element)
             testfunc(element)
-            output = '\n'.join(arrstrip(postprocessing(writer.buf)))  # Don't care about initial blank
+            output = postrendering('\n'.join(arrstrip(postprocessing(writer.buf))))  # Don't care about initial blank
             diff_test(self, valid, output, validpath.replace('valid', 'failed'))
 
     def test_references(self):
@@ -209,6 +251,9 @@ class WriterElementTest(unittest.TestCase):
     def test_textwrap(self):
         return self.function_test("textwrap", "write_section_rec")
 
+    def test_slashbreak(self):
+        return self.function_test("slashbreak", "write_section_rec")
+
     def test_abbreviations(self):
         return self.function_test("abbreviations", "write_t_rec")
 
