@@ -1,7 +1,7 @@
 
 
 # Static values
-__version__  = '2.8.5'
+__version__  = '2.9.6'
 NAME         = 'xml2rfc'
 VERSION      = [ int(i) if i.isdigit() else i for i in __version__.split('.') ]
 CACHES       = ['/var/cache/xml2rfc', '~/.cache/xml2rfc']  # Ordered by priority
@@ -10,10 +10,11 @@ NET_SUBDIRS  = ['bibxml', 'bibxml2', 'bibxml3', 'bibxml4', 'bibxml5']
 
 from xml2rfc.parser import  XmlRfcError, CachingResolver, XmlRfcParser, XmlRfc
 from xml2rfc.writers import BaseRfcWriter, RawTextRfcWriter, PaginatedTextRfcWriter
-from xml2rfc.writers import HtmlRfcWriter, NroffRfcWriter, ExpandedXmlWriter, RfcWriterError, V2v3XmlWriter
+from xml2rfc.writers import HtmlRfcWriter, NroffRfcWriter, ExpandedXmlWriter
+from xml2rfc.writers import RfcWriterError, V2v3XmlWriter, PrepToolWriter
 
 __all__ = ['XmlRfcError', 'CachingResolver', 'XmlRfcParser', 'XmlRfc',
            'BaseRfcWriter', 'RawTextRfcWriter', 'PaginatedTextRfcWriter',
            'HtmlRfcWriter', 'NroffRfcWriter', 'ExpandedXmlWriter',
-           'RfcWriterError', 'V2v3XmlWriter', ]
+           'RfcWriterError', 'V2v3XmlWriter', 'PrepToolWriter', ]
 
