@@ -374,7 +374,7 @@ class XmlRfcParser:
 
 
     """ XML parser container with callbacks to construct an RFC tree """
-    def __init__(self, source, verbose=False, quiet=False,
+    def __init__(self, source, verbose=False, quiet=False, options=None,
                  cache_path=None, templates_path=None, library_dirs=None,
                  no_network=False, network_locs=[
                      'https://xml2rfc.ietf.org/public/rfc/',
@@ -394,7 +394,10 @@ class XmlRfcParser:
         self.templates_path = templates_path or \
                               os.path.join(os.path.dirname(xml2rfc.__file__),
                                            'templates')
-        self.default_dtd_path = os.path.join(self.templates_path, 'rfc2629.dtd')
+        if options and options.vocabulary == 'v2':
+            self.default_dtd_path = os.path.join(self.templates_path, 'rfc2629.dtd')
+        else:
+            self.default_dtd_path = None
 
         for prefix, value in self.nsmap.items():
             lxml.etree.register_namespace(prefix, value)
@@ -429,7 +432,7 @@ class XmlRfcParser:
     def delete_cache(self, path=None):
         self.cachingResolver.delete_cache(path=path)
 
-    def parse(self, remove_comments=True, remove_pis=False, quiet=False, strip_cdata=True):
+    def parse(self, remove_comments=True, remove_pis=False, quiet=False, strip_cdata=True, normalize=False):
         """ Parses the source XML file and returns an XmlRfc instance """
         if not (self.quiet or quiet):
             xml2rfc.log.write('Parsing file', self.source)
@@ -517,6 +520,7 @@ class XmlRfcParser:
         file = six.BytesIO(self.text)
         tree = lxml.etree.parse(file, parser)
         xmlrfc = XmlRfc(tree, self.default_dtd_path, nsmap=self.nsmap)
+        xmlrfc.source = self.source
 
         # Evaluate processing instructions before root element
         xmlrfc._eval_pre_pi()
@@ -568,8 +572,10 @@ class XmlRfcParser:
                 if isinstance(element, AnnotatedElement):
                     element.pis = pis
                     xmlrfc._elements_cache.append(element)                    
+
         # Finally, do any extra formatting on the RFC before returning
-        xmlrfc._format_whitespace()
+        if normalize:
+            xmlrfc._format_whitespace()
 
         return xmlrfc
 
@@ -670,12 +676,12 @@ class XmlRfc:
         else:
             dtd = self.tree.docinfo.externalDTD
             
-        if not dtd:
+        if not dtd and self.default_dtd_path:
             # No explicit DTD filename OR declaration in document!
             xml2rfc.log.warn('No DTD given, defaulting to', self.default_dtd_path)
             return self.validate(dtd_path=self.default_dtd_path)
 
-        if dtd.validate(self.getroot()):
+        if not dtd or dtd.validate(self.getroot()):
             # The document was valid
             return True, []
         else:
