@@ -4,9 +4,18 @@
 
 # Internal utitlity functions.  Not meant for public usage.
 
+import base64
+import calendar
 import re
+import six
 import textwrap
 
+if six.PY2:
+    from urllib import quote
+else:
+    from urllib.request import quote
+    
+
 try:
     import debug
     assert debug
@@ -543,3 +552,21 @@ _slash_replacements = [
 ];
 
             
+def build_dataurl(mime, data, base64enc=False):
+    if base64enc:
+        data = quote(base64.b64encode(data))
+        url = "data:%s;base64,%s" % (mime, data)
+    else:
+        data = quote(data)
+        url = "data:%s,%s" % (mime, data)
+    return url
+
+def normalize_month(month):
+    if len(month) < 3:
+        xml2rfc.log.error("Expected a month name with at least 3 letters, found '%s'" % (month, ))
+    for i, m in enumerate(calendar.month_name):
+        if m and m.lower().startswith(month.lower()):
+            month = '%02d' % (i)
+    assert month.isdigit()
+    return month
+
