@@ -7,7 +7,8 @@ from xml2rfc.writers.html import HtmlRfcWriter
 from xml2rfc.writers.nroff import NroffRfcWriter
 from xml2rfc.writers.expanded_xml import ExpandedXmlWriter
 from xml2rfc.writers.v2v3 import V2v3XmlWriter
+from xml2rfc.writers.preptool import PrepToolWriter
 
 __all__ = ['BaseRfcWriter', 'RawTextRfcWriter', 'PaginatedTextRfcWriter',
            'HtmlRfcWriter', 'NroffRfcWriter', 'ExpandedXmlWriter',
-           'RfcWriterError', 'V2v3XmlWriter', ]
+           'RfcWriterError', 'V2v3XmlWriter', 'PrepToolWriter', ]
