@@ -20,8 +20,8 @@ except ImportError:
 
 def slugify(s):
     s = s.strip().lower()
-    s = re.sub(r'[^\w\s/|-]', '', s)
-    s = re.sub(r'[-_\s/|]+', '_', s)
+    s = re.sub(r'[^\w\s/|@=-]', '', s)
+    s = re.sub(r'[-_\s/|@=]+', '_', s)
     s = s.strip('_')
     return s
 
@@ -296,10 +296,15 @@ class V2v3XmlWriter:
             # handle mixed block/non-block content surrounding all block nodes
             './/*[self::artwork or self::dl or self::figure or self::ol or self::sourcecode or self::t or self::ul]',
             './/*[@*="yes" or @*="no"]',      # convert old attribute false/true
+            '.;pretty_print_prep()',
         ]
 
+        # replace the vocabulary v2 dtd, but keep some entity definitions.
+        tree = self.root.getroottree()
+        tree.docinfo.system_url = "rfc2629-xhtml.ent"
+
         for s in selectors:
-            slug = slugify(s.replace('self::', '').replace(' or ','_'))
+            slug = slugify(s.replace('self::', '').replace(' or ','_').replace(';','_'))
             if '@' in s:
                 func_name = 'attribute_%s' % slug
             elif "()" in s:
@@ -308,13 +313,16 @@ class V2v3XmlWriter:
                 if not slug:
                     slug = 'rfc'
                 func_name = 'element_%s' % slug
+            # get rid of selector annotation
+            ss = s.split(';')[0]
             func = getattr(self, func_name, None)
             if func:
-                #log.note("Processing %s" % slug)
-                for e in self.root.xpath(s):
+                if self.options.debug:
+                    log.note("Calling %s()" % func_name)
+                for e in self.root.xpath(ss):
                     func(e, e.getparent())
             else:
-                log.note("No handler for %s" % slug)
+                log.warn("No handler for function %s, slug %s" % (func_name, slug, ))
 
     # ----------------------------------------------------------------------
 
@@ -527,16 +535,20 @@ class V2v3XmlWriter:
         front = e.find('./front')
         title = e.find('./front/title')
         i = front.index(title) + 1
-        if 'category' in e.attrib:
-            attr = {'name': e.get('category'), 'value': '', }
-            if 'seriesNo' in e.attrib:
-                attr['value'] = e.get('seriesNo')
+        if 'category' in e.attrib and 'seriesNo' in e.attrib:
+            attr = {
+                'name': e.get('category'),
+                'value': e.get('seriesNo')
+            }
             front.insert(i, self.element('seriesInfo', **attr))
+            stripattr(e, ['seriesNo', ]) # keep 'category' for use in preptool
         if 'number' in e.attrib:
-            front.insert(i, self.element('seriesInfo', name="RFC", value=e.get('category')))
-        if 'docName' in e.attrib:
+            front.insert(i, self.element('seriesInfo', name="RFC", value=e.get('number')))
+            if 'docName' in e.attrib:
+                e.insert(0, self.element('link', rel='convertedFrom', href="https://datatracker.ietf.org/doc/%s"%(e.get('docName'), )))
+        elif 'docName' in e.attrib:
             front.insert(i, self.element('seriesInfo', name="Internet-Draft", value=e.get('docName')))
-        stripattr(e, ['category', 'docName', 'number', 'seriesNo' 'xi'])
+        stripattr(e, ['docName', 'number', 'xi'])
 
     # 2.47.  <seriesInfo>
     # 
@@ -957,7 +969,7 @@ class V2v3XmlWriter:
                 e.set(k, id)
                 
 
-    def attribute_xreftarget(self, e, p):
+    def attribute_xref_target(self, e, p):
         k = 'target'
         if k in e.keys():
             v = e.get(k)
